@@ -1,7 +1,6 @@
 package certificate
 
 import (
-	"bytes"
 	"crypto"
 	"crypto/ecdsa"
 	"crypto/ed25519"
@@ -14,6 +13,7 @@ import (
 
 	"github.com/pkg/errors"
 	"github.com/smallstep/cli/flags"
+	"github.com/smallstep/cli/internal/cryptoutil"
 	"github.com/smallstep/cli/utils"
 	"github.com/urfave/cli"
 	"go.step.sm/cli-utils/errs"
@@ -37,7 +37,8 @@ func signCommand() cli.Command {
 		Action: cli.ActionFunc(signAction),
 		Usage:  "sign a certificate signing request (CSR)",
 		UsageText: `**step certificate sign** <csr-file> <crt-file> <key-file>
-[**--profile**=<profile>] [**--template**=<file>]
+[**--profile**=<profile>] [**--template**=<file>] 
+[**--set**=<key=value>] [**--set-file**=<file>]
 [**--password-file**=<file>] [**--path-len**=<maximum>]
 [**--not-before**=<time|duration>] [**--not-after**=<time|duration>]
 [**--bundle**]`,
@@ -110,8 +111,48 @@ $ cat coyote.tpl
 }
 $ step certificate create --csr coyote@acme.corp coyote.csr coyote.key
 $ step certificate sign --template coyote.tpl coyote.csr issuer.crt issuer.key
-'''`,
+'''
+
+Sign a CSR using a template and allow configuring the subject using the
+**--set** and **--set-file** flags.
+'''
+$ cat rocket.tpl
+{
+	"subject": {
+		"country": {{ toJson .Insecure.User.country }},
+		"organization": {{ toJson .Insecure.User.organization }},
+		"organizationalUnit": {{ toJson .Insecure.User.organizationUnit }},
+		"commonName": {{toJson .Subject.CommonName }}
+	},
+	"sans": {{ toJson .SANs }},
+{{- if typeIs "*rsa.PublicKey" .Insecure.CR.PublicKey }}
+	"keyUsage": ["keyEncipherment", "digitalSignature"],
+{{- else }}
+	"keyUsage": ["digitalSignature"],
+{{- end }}
+	"extKeyUsage": ["serverAuth", "clientAuth"]
+}
+$ cat organization.json
+{
+	"country": "US",
+	"organization": "Acme Corporation",
+	"organizationUnit": "HQ"
+}
+$ step certificate create --csr rocket.acme.corp rocket.csr rocket.key
+$ step certificate sign --template rocket.tpl \
+  --set-file organization.json --set organizationUnit=Engineering \
+  rocket.csr issuer.crt issuer.key
+'''
+
+Sign a CSR using <step-kms-plugin>:
+'''
+$ step certificate sign \
+  --kms 'pkcs11:module-path=/usr/local/lib/softhsm/libsofthsm2.so;token=smallstep?pin-value=password' \
+  leaf.csr issuer.crt 'pkcs11:id=4001'
+'''
+`,
 		Flags: []cli.Flag{
+			flags.KMSUri,
 			cli.StringFlag{
 				Name:  "profile",
 				Value: profileLeaf,
@@ -130,10 +171,9 @@ $ step certificate sign --template coyote.tpl coyote.csr issuer.crt issuer.key
     **csr**
     :  Signs a x.509 certificate without modifying the CSR.`,
 			},
-			cli.StringFlag{
-				Name:  "template",
-				Usage: `The certificate template <file>, a JSON representation of the certificate to create.`,
-			},
+			flags.Template,
+			flags.TemplateSet,
+			flags.TemplateSetFile,
 			flags.PasswordFile,
 			cli.StringFlag{
 				Name: "not-before",
@@ -188,24 +228,24 @@ func signAction(ctx *cli.Context) error {
 	if err != nil {
 		return err
 	}
-	ops := []pemutil.Options{}
+	opts := []pemutil.Options{}
 	passFile := ctx.String("password-file")
 	if passFile == "" {
-		ops = append(ops, pemutil.WithPasswordPrompt(
+		opts = append(opts, pemutil.WithPasswordPrompt(
 			fmt.Sprintf("Please enter the password to decrypt %s", keyFile),
 			func(s string) ([]byte, error) {
 				return ui.PromptPassword(s)
 			}))
 	} else {
-		ops = append(ops, pemutil.WithPasswordFile(passFile))
+		opts = append(opts, pemutil.WithPasswordFile(passFile))
 	}
-	key, err := pemutil.Read(keyFile, ops...)
+
+	signer, err := cryptoutil.CreateSigner(ctx.String("kms"), keyFile, opts...)
 	if err != nil {
 		return err
 	}
-	signer, ok := key.(crypto.Signer)
-	if !ok {
-		return errors.Errorf("key in %s does not satisfy the crypto.Signer interface", keyFile)
+	if !cryptoutil.IsX509Signer(signer) {
+		return errors.Errorf("the key %q cannot be used to sign X509 certificates", keyFile)
 	}
 	if err := validateIssuerKey(issuers[0], signer); err != nil {
 		return err
@@ -225,12 +265,19 @@ func signAction(ctx *cli.Context) error {
 
 	// Read template if passed. If not use a template depending on the profile.
 	var template string
+	var userData map[string]interface{}
 	if templateFile != "" {
 		b, err := utils.ReadFile(templateFile)
 		if err != nil {
 			return err
 		}
 		template = string(b)
+
+		// Parse --set and --set-file
+		userData, err = flags.GetTemplateData(ctx)
+		if err != nil {
+			return err
+		}
 	} else {
 		switch profile {
 		case profileLeaf:
@@ -281,6 +328,7 @@ func signAction(ctx *cli.Context) error {
 
 	// Create certificate template from csr.
 	data := createTemplateData(csr, maxPathLen)
+	data.SetUserData(userData)
 	tpl, err := x509util.NewCertificate(csr, x509util.WithTemplate(template, data))
 	if err != nil {
 		return err
@@ -322,27 +370,27 @@ func signAction(ctx *cli.Context) error {
 func validateIssuerKey(crt *x509.Certificate, signer crypto.Signer) error {
 	switch pub := crt.PublicKey.(type) {
 	case *rsa.PublicKey:
-		priv, ok := signer.(*rsa.PrivateKey)
+		pk, ok := signer.Public().(*rsa.PublicKey)
 		if !ok {
 			return errors.New("private key type does not match issuer public key type")
 		}
-		if pub.N.Cmp(priv.N) != 0 {
+		if !pub.Equal(pk) {
 			return errors.New("private key does not match issuer public key")
 		}
 	case *ecdsa.PublicKey:
-		priv, ok := signer.(*ecdsa.PrivateKey)
+		pk, ok := signer.Public().(*ecdsa.PublicKey)
 		if !ok {
 			return errors.New("private key type does not match issuer public key type")
 		}
-		if pub.X.Cmp(priv.X) != 0 || pub.Y.Cmp(priv.Y) != 0 {
+		if !pub.Equal(pk) {
 			return errors.New("private key does not match issuer public key")
 		}
 	case ed25519.PublicKey:
-		priv, ok := signer.(ed25519.PrivateKey)
+		pk, ok := signer.Public().(ed25519.PublicKey)
 		if !ok {
 			return errors.New("private key type does not match issuer public key type")
 		}
-		if !bytes.Equal(priv.Public().(ed25519.PublicKey), pub) {
+		if !pub.Equal(pk) {
 			return errors.New("private key does not match issuer public key")
 		}
 	default:
