@@ -7,8 +7,9 @@ import (
 	"os"
 
 	"github.com/pkg/errors"
-	"github.com/smallstep/cli/jose"
 	"github.com/urfave/cli"
+	"go.step.sm/cli-utils/ui"
+	"go.step.sm/crypto/jose"
 )
 
 func publicCommand() cli.Command {
@@ -32,7 +33,9 @@ func publicAction(ctx *cli.Context) error {
 
 	jwk := new(jose.JSONWebKey)
 	// Attempt to decrypt if encrypted
-	if b, err = jose.Decrypt("Please enter the password to decrypt your private JWK", b); err != nil {
+	if b, err = jose.Decrypt(b, jose.WithPasswordPrompter("Please enter the password to decrypt your private JWK", func(s string) ([]byte, error) {
+		return ui.PromptPassword(s)
+	})); err != nil {
 		return err
 	}
 
