@@ -21,14 +21,14 @@ import (
 	"time"
 
 	"github.com/pkg/errors"
-	"github.com/smallstep/cli/crypto/randutil"
 	"github.com/smallstep/cli/exec"
 	"github.com/smallstep/cli/flags"
-	"github.com/smallstep/cli/jose"
 	"github.com/smallstep/cli/utils"
 	"github.com/urfave/cli"
 	"go.step.sm/cli-utils/command"
 	"go.step.sm/cli-utils/errs"
+	"go.step.sm/crypto/jose"
+	"go.step.sm/crypto/randutil"
 )
 
 // These are the OAuth2.0 client IDs from the Step CLI. This application is
@@ -185,11 +185,7 @@ $ step oauth --client-id my-client-id --client-secret my-client-secret \
 			cli.BoolFlag{
 				Name: "console, c",
 				Usage: `Complete the flow while remaining only inside the terminal.
-
-NOTE: This flag will continue to use the Out of Band (OOB) flow for Google OAuth clients
-until Oct 3, 2022 when the OOB flow will be shut off. All other OAuth clients
-will default to using the Device Authorization Grant flow
-(https://datatracker.ietf.org/doc/html/rfc8628#section-3.2).`,
+This flag defaults to use the Device Authorization Grant flow.`,
 			},
 			cli.StringFlag{
 				Name: "console-flow",
@@ -332,8 +328,8 @@ type options struct {
 
 // Validate validates the options.
 func (o *options) Validate() error {
-	if o.Provider != "google" && !strings.HasPrefix(o.Provider, "https://") {
-		return errors.New("use a valid provider: google")
+	if o.Provider != "google" && o.Provider != "github" && !strings.HasPrefix(o.Provider, "https://") {
+		return errors.New("use a valid provider: google or github")
 	}
 	if o.CallbackListener != "" {
 		if _, _, err := net.SplitHostPort(o.CallbackListener); err != nil {
@@ -385,14 +381,8 @@ func oauthCmd(c *cli.Context) error {
 	case c.IsSet("console-flow"):
 		return errs.InvalidFlagValue(c, "console-flow", consoleFlowInput, "device, oob")
 	case c.Bool("console"):
-		oobDeprecationDate := time.Date(2022, time.October, 3, 0, 0, 0, 0, time.UTC)
-		if time.Now().Before(oobDeprecationDate) && (opts.Provider == "google" || strings.HasPrefix(opts.Provider, "https://accounts.google.com")) {
-			isOOBFlow = true
-			opts.ConsoleFlow = oobConsoleFlow
-		} else {
-			isDeviceFlow = true
-			opts.ConsoleFlow = deviceConsoleFlow
-		}
+		isDeviceFlow = true
+		opts.ConsoleFlow = deviceConsoleFlow
 	}
 
 	var clientID, clientSecret string
@@ -573,6 +563,28 @@ type oauth struct {
 	tokCh               chan *token
 }
 
+type endpoint struct {
+	authorization       string
+	deviceAuthorization string
+	token               string
+	userInfo            string
+}
+
+var knownProviders = map[string]endpoint{
+	"google": {
+		authorization:       "https://accounts.google.com/o/oauth2/v2/auth",
+		deviceAuthorization: "https://oauth2.googleapis.com/device/code",
+		token:               "https://www.googleapis.com/oauth2/v4/token",
+		userInfo:            "https://www.googleapis.com/oauth2/v3/userinfo",
+	},
+	"github": {
+		authorization:       "https://github.com/login/oauth/authorize",
+		deviceAuthorization: "https://github.com/login/device/code",
+		token:               "https://github.com/login/oauth/access_token",
+		userInfo:            "https://api.github.com/user",
+	},
+}
+
 func newOauth(provider, clientID, clientSecret, authzEp, deviceAuthzEp, tokenEp, scope, prompt string, authParams url.Values, opts *options) (*oauth, error) {
 	state, err := randutil.Alphanumeric(32)
 	if err != nil {
@@ -589,71 +601,18 @@ func newOauth(provider, clientID, clientSecret, authzEp, deviceAuthzEp, tokenEp,
 		return nil, err
 	}
 
-	switch provider {
-	case "google":
+	// Check known providers
+	if p, ok := knownProviders[provider]; ok {
 		return &oauth{
 			provider:            provider,
 			clientID:            clientID,
 			clientSecret:        clientSecret,
 			scope:               scope,
 			prompt:              prompt,
-			authzEndpoint:       "https://accounts.google.com/o/oauth2/v2/auth",
-			deviceAuthzEndpoint: "https://oauth2.googleapis.com/device/code",
-			tokenEndpoint:       "https://www.googleapis.com/oauth2/v4/token",
-			userInfoEndpoint:    "https://www.googleapis.com/oauth2/v3/userinfo",
-			loginHint:           opts.Email,
-			state:               state,
-			codeChallenge:       challenge,
-			nonce:               nonce,
-			implicit:            opts.Implicit,
-			CallbackListener:    opts.CallbackListener,
-			CallbackListenerURL: opts.CallbackListenerURL,
-			CallbackPath:        opts.CallbackPath,
-			terminalRedirect:    opts.TerminalRedirect,
-			browser:             opts.Browser,
-			authParams:          authParams,
-			errCh:               make(chan error),
-			tokCh:               make(chan *token),
-		}, nil
-	default:
-		userinfoEp := ""
-
-		isDeviceFlow := opts.Console && opts.ConsoleFlow == deviceConsoleFlow
-
-		if (isDeviceFlow && deviceAuthzEp == "" && tokenEp == "") ||
-			(!isDeviceFlow && authzEp == "" && tokenEp == "") {
-			d, err := disco(provider)
-			if err != nil {
-				return nil, err
-			}
-
-			if v, ok := d["device_authorization_endpoint"].(string); !ok && isDeviceFlow {
-				return nil, errors.New("missing or invalid 'device_authorization_endpoint' in provider metadata")
-			} else if ok {
-				deviceAuthzEp = v
-			}
-			if v, ok := d["authorization_endpoint"].(string); !ok && !isDeviceFlow {
-				return nil, errors.New("missing or invalid 'authorization_endpoint' in provider metadata")
-			} else if ok {
-				authzEp = v
-			}
-			v, ok := d["token_endpoint"].(string)
-			if !ok {
-				return nil, errors.New("missing or invalid 'token_endpoint' in provider metadata")
-			}
-			tokenEp, userinfoEp = v, v
-		}
-
-		return &oauth{
-			provider:            provider,
-			clientID:            clientID,
-			clientSecret:        clientSecret,
-			scope:               scope,
-			prompt:              prompt,
-			authzEndpoint:       authzEp,
-			deviceAuthzEndpoint: deviceAuthzEp,
-			tokenEndpoint:       tokenEp,
-			userInfoEndpoint:    userinfoEp,
+			authzEndpoint:       p.authorization,
+			deviceAuthzEndpoint: p.deviceAuthorization,
+			tokenEndpoint:       p.token,
+			userInfoEndpoint:    p.userInfo,
 			loginHint:           opts.Email,
 			state:               state,
 			codeChallenge:       challenge,
@@ -669,6 +628,57 @@ func newOauth(provider, clientID, clientSecret, authzEp, deviceAuthzEp, tokenEp,
 			tokCh:               make(chan *token),
 		}, nil
 	}
+
+	userinfoEp := ""
+	isDeviceFlow := opts.Console && opts.ConsoleFlow == deviceConsoleFlow
+
+	if (isDeviceFlow && deviceAuthzEp == "" && tokenEp == "") || (!isDeviceFlow && authzEp == "" && tokenEp == "") {
+		d, err := disco(provider)
+		if err != nil {
+			return nil, err
+		}
+
+		if v, ok := d["device_authorization_endpoint"].(string); !ok && isDeviceFlow {
+			return nil, errors.New("missing or invalid 'device_authorization_endpoint' in provider metadata")
+		} else if ok {
+			deviceAuthzEp = v
+		}
+		if v, ok := d["authorization_endpoint"].(string); !ok && !isDeviceFlow {
+			return nil, errors.New("missing or invalid 'authorization_endpoint' in provider metadata")
+		} else if ok {
+			authzEp = v
+		}
+		v, ok := d["token_endpoint"].(string)
+		if !ok {
+			return nil, errors.New("missing or invalid 'token_endpoint' in provider metadata")
+		}
+		tokenEp, userinfoEp = v, v
+	}
+
+	return &oauth{
+		provider:            provider,
+		clientID:            clientID,
+		clientSecret:        clientSecret,
+		scope:               scope,
+		prompt:              prompt,
+		authzEndpoint:       authzEp,
+		deviceAuthzEndpoint: deviceAuthzEp,
+		tokenEndpoint:       tokenEp,
+		userInfoEndpoint:    userinfoEp,
+		loginHint:           opts.Email,
+		state:               state,
+		codeChallenge:       challenge,
+		nonce:               nonce,
+		implicit:            opts.Implicit,
+		CallbackListener:    opts.CallbackListener,
+		CallbackListenerURL: opts.CallbackListenerURL,
+		CallbackPath:        opts.CallbackPath,
+		terminalRedirect:    opts.TerminalRedirect,
+		browser:             opts.Browser,
+		authParams:          authParams,
+		errCh:               make(chan error),
+		tokCh:               make(chan *token),
+	}, nil
 }
 
 func disco(provider string) (map[string]interface{}, error) {
@@ -698,6 +708,19 @@ func disco(provider string) (map[string]interface{}, error) {
 	return details, err
 }
 
+// postForm simulates http.PostForm but adds the header "Accept:
+// application/json", without this header GitHub will use
+// application/x-www-form-urlencoded.
+func postForm(rawurl string, data url.Values) (*http.Response, error) {
+	req, err := http.NewRequest("POST", rawurl, strings.NewReader(data.Encode()))
+	if err != nil {
+		return nil, fmt.Errorf("create POST %s request failed: %w", rawurl, err)
+	}
+	req.Header.Set("Content-Type", "application/x-www-form-urlencoded")
+	req.Header.Set("Accept", "application/json")
+	return http.DefaultClient.Do(req)
+}
+
 // NewServer creates http server
 func (o *oauth) NewServer() (*httptest.Server, error) {
 	if o.CallbackListener == "" {
@@ -836,7 +859,7 @@ func (o *oauth) DoDeviceAuthorization() (*token, error) {
 	data.Set("client_secret", o.clientSecret)
 	data.Set("scope", o.scope)
 
-	resp, err := http.PostForm(o.deviceAuthzEndpoint, data)
+	resp, err := postForm(o.deviceAuthzEndpoint, data)
 	if err != nil {
 		return nil, errors.Wrap(err, "http failure to identify device")
 	}
@@ -857,7 +880,7 @@ func (o *oauth) DoDeviceAuthorization() (*token, error) {
 
 	var idr identifyDeviceResponse
 	if err := json.NewDecoder(bytes.NewReader(b)).Decode(&idr); err != nil {
-		return nil, errors.Wrap(err, "failure decoding device authz response to JWON")
+		return nil, errors.Wrap(err, "failure decoding device authz response to JSON")
 	}
 
 	switch {
@@ -923,7 +946,7 @@ func openBrowserIfAsked(o *oauth, u string) {
 var errHTTPToken = errors.New("bad request; token not returned")
 
 func (o *oauth) deviceAuthzTokenPoll(data url.Values) (*token, error) {
-	resp, err := http.PostForm(o.tokenEndpoint, data)
+	resp, err := postForm(o.tokenEndpoint, data)
 	if err != nil {
 		return nil, errors.Wrap(err, "error doing POST to /token endpoint")
 	}
@@ -996,7 +1019,7 @@ func (o *oauth) DoTwoLeggedAuthorization(issuer string) (*token, error) {
 	}
 
 	// Send the POST request and return token.
-	resp, err := http.PostForm(o.tokenEndpoint, params)
+	resp, err := postForm(o.tokenEndpoint, params)
 	if err != nil {
 		return nil, errors.Wrapf(err, "error from token endpoint")
 	}
@@ -1203,9 +1226,7 @@ func (o *oauth) Exchange(tokenEndpoint, code string) (*token, error) {
 	data.Set("grant_type", "authorization_code")
 	data.Set("code_verifier", o.codeChallenge)
 
-	//nolint:gosec // Tainted url deemed acceptable. Not used to store any
-	// backend data.
-	resp, err := http.PostForm(tokenEndpoint, data)
+	resp, err := postForm(tokenEndpoint, data)
 	if err != nil {
 		return nil, errors.WithStack(err)
 	}
@@ -1222,17 +1243,66 @@ func (o *oauth) Exchange(tokenEndpoint, code string) (*token, error) {
 func (o *oauth) success(w http.ResponseWriter) {
 	w.WriteHeader(http.StatusOK)
 	w.Header().Add("Content-Type", "text/plain; charset=utf-8")
-	w.Write([]byte(`<html><head><title>OAuth Request Successful</title>`))
-	w.Write([]byte(`</head><body><p style='font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"; font-size: 22px; color: #333; width: 400px; margin: 0 auto; text-align: center; line-height: 1.7; padding: 20px;'>`))
-	w.Write([]byte(`<strong style='font-size: 28px; color: #000;'>Success</strong><br />Look for the token on the command line`))
-	w.Write([]byte(`</p></body></html>`))
+
+	w.Write([]byte(`<html lang="en-US">`))
+	w.Write([]byte(`<head><title>OAuth Request Successful</title>`))
+	w.Write([]byte(`</head>`))
+	w.Write([]byte(`<body style='background-color: rgb(238, 246, 252);text-align:center;font-family: open sans, sans-serif; font-size: 22px; color: #333; width: 400px; margin: 0 auto; text-align: center; line-height: 1.7; padding: 20px;'>`))
+	w.Write([]byte(`<div style="margin:auto;width:56px;">`))
+	w.Write([]byte(`<svg width="56" height="61" viewBox="0 0 56 61" fill="none" xmlns="http://www.w3.org/2000/svg" style="alignment: center">`))
+	w.Write([]byte(`<g filter="url(#filter0_d)">`))
+	w.Write([]byte(`<path fill-rule="evenodd" clip-rule="evenodd" d="M50 38.0623L50 22.5532C50 20.0715 48.6641 17.77 46.4774 16.485L33.7817 9.02489C31.4569 7.65849 28.5431 7.65849 26.2183 9.02489L13.5226 16.485C11.3359 17.77 10 20.0715 10 22.5532L10 38.0623C10 40.544 11.3359 42.8455 13.5226 44.1305L26.2183 51.5909C28.5431 52.957 31.4569 52.957 33.7817 51.5909L46.4774 44.1305C48.6641 42.8455 50 40.544 50 38.0623Z" fill="white"/>`))
+	w.Write([]byte(`</g>`))
+	w.Write([]byte(`<path d="M26.1994 21.6989C26.5136 23.3294 28.3272 24.7249 28.9555 25.1068L35.8387 29.2344C36.5098 29.6164 40.3227 31.9813 41.7936 36.2852C41.8364 36.388 41.9364 36.4615 42.0363 36.4615C42.1791 36.4615 42.3077 36.344 42.3077 36.1824V24.5633C42.3077 23.917 41.9649 23.3147 41.408 23.0063L40.1085 22.2718C39.8372 22.1249 39.5087 22.2131 39.3516 22.4922L37.5523 25.7091C37.3952 25.9882 37.0525 26.0763 36.7812 25.9147L31.4689 22.7566C31.1976 22.595 31.1119 22.2424 31.269 21.9633L32.9969 18.8786C33.1682 18.5702 33.0397 18.1883 32.7256 18.056C32.1829 17.821 31.526 17.586 31.4689 17.5566C30.1123 17.1013 28.1987 16.9397 27.2848 18.3205C26.6421 19.2899 25.971 20.4651 26.1994 21.6989Z" fill="#DC4B40"/>`))
+	w.Write([]byte(`<path d="M34.5697 38.9163C34.2555 37.2859 32.4419 35.8904 31.8136 35.5085L24.9304 31.3808C24.2593 30.9989 20.4464 28.634 18.9755 24.3301C18.9327 24.2273 18.8327 24.1538 18.7328 24.1538C18.5899 24.1538 18.4614 24.2713 18.4614 24.4329V36.0667C18.4614 36.713 18.8042 37.3152 19.3611 37.6237L20.6606 38.3582C20.9319 38.5051 21.2604 38.4169 21.4175 38.1378L23.2025 34.9209C23.3596 34.6418 23.7023 34.5537 23.9736 34.7153L29.2859 37.8734C29.5573 38.035 29.6429 38.3875 29.4859 38.6666L27.7722 41.7367C27.6009 42.0451 27.7294 42.427 28.0435 42.5592C28.5862 42.7943 29.2431 43.0293 29.3002 43.0587C30.6426 43.514 32.5561 43.6756 33.4701 42.2948C34.127 41.3254 34.7982 40.1502 34.5697 38.9163Z" fill="#DC4B40"/>`))
+	w.Write([]byte(`<defs>`))
+	w.Write([]byte(`<filter id="filter0_d" x="0" y="0" width="56" height="60.6154" filterUnits="userSpaceOnUse" color-interpolation-filters="sRGB">`))
+	w.Write([]byte(`<feFlood flood-opacity="0" result="BackgroundImageFix"/>`))
+	w.Write([]byte(`<feColorMatrix in="SourceAlpha" type="matrix" values="0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0"/>`))
+	w.Write([]byte(`<feOffset dx="-2"/>`))
+	w.Write([]byte(`<feGaussianBlur stdDeviation="4"/>`))
+	w.Write([]byte(`<feColorMatrix type="matrix" values="0 0 0 0 0.13245 0 0 0 0 0.185971 0 0 0 0 0.444462 0 0 0 0.211532 0"/>`))
+	w.Write([]byte(`<feBlend mode="normal" in2="BackgroundImageFix" result="effect1_dropShadow"/>`))
+	w.Write([]byte(`<feBlend mode="normal" in="SourceGraphic" in2="effect1_dropShadow" result="shape"/>`))
+	w.Write([]byte(`</filter>`))
+	w.Write([]byte(`</defs>`))
+	w.Write([]byte(`</svg>`))
+	w.Write([]byte(`</div>`))
+	w.Write([]byte(`<p style='font-size: 20px;'>`))
+	w.Write([]byte(`<strong style='font-size: 28px; color: #000;'>Success</strong><br/>OAuth Request Successful.<br/>Look for the token on the command line.`))
+	w.Write([]byte(`</p>`))
+	w.Write([]byte(`</body>`))
+	w.Write([]byte(`</html>`))
 }
 
 func (o *oauth) badRequest(w http.ResponseWriter, msg string) {
 	w.WriteHeader(http.StatusBadRequest)
 	w.Header().Add("Content-Type", "text/plain; charset=utf-8")
-	w.Write([]byte(`<html><head><title>OAuth Request Unsuccessful</title>`))
-	w.Write([]byte(`</head><body><p style='font-family: -apple-system, BlinkMacSystemFont, "Segoe UI", Helvetica, Arial, sans-serif, "Apple Color Emoji", "Segoe UI Emoji", "Segoe UI Symbol"; font-size: 22px; color: #333; width: 400px; margin: 0 auto; text-align: center; line-height: 1.7; padding: 20px;'>`))
+	w.Write([]byte(`<html lang="en-US">`))
+	w.Write([]byte(`<head><title>OAuth Request Unsuccessful</title>`))
+	w.Write([]byte(`</head>`))
+	w.Write([]byte(`<body style='background-color: rgb(238, 246, 252);text-align:center;font-family: open sans, sans-serif; font-size: 22px; color: #333; width: 400px; margin: 0 auto; text-align: center; line-height: 1.7; padding: 20px;'>`))
+	w.Write([]byte(`<div style="margin:auto;width:56px;">`))
+	w.Write([]byte(`<svg width="56" height="61" viewBox="0 0 56 61" fill="none" xmlns="http://www.w3.org/2000/svg" style="alignment: center">`))
+	w.Write([]byte(`<g filter="url(#filter0_d)">`))
+	w.Write([]byte(`<path fill-rule="evenodd" clip-rule="evenodd" d="M50 38.0623L50 22.5532C50 20.0715 48.6641 17.77 46.4774 16.485L33.7817 9.02489C31.4569 7.65849 28.5431 7.65849 26.2183 9.02489L13.5226 16.485C11.3359 17.77 10 20.0715 10 22.5532L10 38.0623C10 40.544 11.3359 42.8455 13.5226 44.1305L26.2183 51.5909C28.5431 52.957 31.4569 52.957 33.7817 51.5909L46.4774 44.1305C48.6641 42.8455 50 40.544 50 38.0623Z" fill="white"/>`))
+	w.Write([]byte(`</g>`))
+	w.Write([]byte(`<path d="M26.1994 21.6989C26.5136 23.3294 28.3272 24.7249 28.9555 25.1068L35.8387 29.2344C36.5098 29.6164 40.3227 31.9813 41.7936 36.2852C41.8364 36.388 41.9364 36.4615 42.0363 36.4615C42.1791 36.4615 42.3077 36.344 42.3077 36.1824V24.5633C42.3077 23.917 41.9649 23.3147 41.408 23.0063L40.1085 22.2718C39.8372 22.1249 39.5087 22.2131 39.3516 22.4922L37.5523 25.7091C37.3952 25.9882 37.0525 26.0763 36.7812 25.9147L31.4689 22.7566C31.1976 22.595 31.1119 22.2424 31.269 21.9633L32.9969 18.8786C33.1682 18.5702 33.0397 18.1883 32.7256 18.056C32.1829 17.821 31.526 17.586 31.4689 17.5566C30.1123 17.1013 28.1987 16.9397 27.2848 18.3205C26.6421 19.2899 25.971 20.4651 26.1994 21.6989Z" fill="#DC4B40"/>`))
+	w.Write([]byte(`<path d="M34.5697 38.9163C34.2555 37.2859 32.4419 35.8904 31.8136 35.5085L24.9304 31.3808C24.2593 30.9989 20.4464 28.634 18.9755 24.3301C18.9327 24.2273 18.8327 24.1538 18.7328 24.1538C18.5899 24.1538 18.4614 24.2713 18.4614 24.4329V36.0667C18.4614 36.713 18.8042 37.3152 19.3611 37.6237L20.6606 38.3582C20.9319 38.5051 21.2604 38.4169 21.4175 38.1378L23.2025 34.9209C23.3596 34.6418 23.7023 34.5537 23.9736 34.7153L29.2859 37.8734C29.5573 38.035 29.6429 38.3875 29.4859 38.6666L27.7722 41.7367C27.6009 42.0451 27.7294 42.427 28.0435 42.5592C28.5862 42.7943 29.2431 43.0293 29.3002 43.0587C30.6426 43.514 32.5561 43.6756 33.4701 42.2948C34.127 41.3254 34.7982 40.1502 34.5697 38.9163Z" fill="#DC4B40"/>`))
+	w.Write([]byte(`<defs>`))
+	w.Write([]byte(`<filter id="filter0_d" x="0" y="0" width="56" height="60.6154" filterUnits="userSpaceOnUse" color-interpolation-filters="sRGB">`))
+	w.Write([]byte(`<feFlood flood-opacity="0" result="BackgroundImageFix"/>`))
+	w.Write([]byte(`<feColorMatrix in="SourceAlpha" type="matrix" values="0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 127 0"/>`))
+	w.Write([]byte(`<feOffset dx="-2"/>`))
+	w.Write([]byte(`<feGaussianBlur stdDeviation="4"/>`))
+	w.Write([]byte(`<feColorMatrix type="matrix" values="0 0 0 0 0.13245 0 0 0 0 0.185971 0 0 0 0 0.444462 0 0 0 0.211532 0"/>`))
+	w.Write([]byte(`<feBlend mode="normal" in2="BackgroundImageFix" result="effect1_dropShadow"/>`))
+	w.Write([]byte(`<feBlend mode="normal" in="SourceGraphic" in2="effect1_dropShadow" result="shape"/>`))
+	w.Write([]byte(`</filter>`))
+	w.Write([]byte(`</defs>`))
+	w.Write([]byte(`</svg>`))
+	w.Write([]byte(`</div>`))
+	w.Write([]byte(`<p style='font-size: 20px;'>`))
 	w.Write([]byte(`<strong style='font-size: 28px; color: red;'>Failure</strong><br />`))
 	w.Write([]byte(msg))
 	w.Write([]byte(`</p></body></html>`))
