@@ -18,7 +18,9 @@ import (
 	"io"
 	"strings"
 	"testing"
+	"time"
 
+	"github.com/jonboulle/clockwork"
 	"github.com/tektoncd/cli/pkg/test"
 	cb "github.com/tektoncd/cli/pkg/test/builder"
 	testDynamic "github.com/tektoncd/cli/pkg/test/dynamic"
@@ -34,6 +36,8 @@ import (
 
 func TestTaskRunDelete(t *testing.T) {
 	version := "v1alpha1"
+	clock := clockwork.NewFakeClock()
+
 	ns := []*corev1.Namespace{
 		{
 			ObjectMeta: metav1.ObjectMeta{
@@ -73,6 +77,11 @@ func TestTaskRunDelete(t *testing.T) {
 				},
 			},
 			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -96,6 +105,11 @@ func TestTaskRunDelete(t *testing.T) {
 				},
 			},
 			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -119,6 +133,11 @@ func TestTaskRunDelete(t *testing.T) {
 				},
 			},
 			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -142,6 +161,11 @@ func TestTaskRunDelete(t *testing.T) {
 				},
 			},
 			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -165,6 +189,11 @@ func TestTaskRunDelete(t *testing.T) {
 				},
 			},
 			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -188,6 +217,40 @@ func TestTaskRunDelete(t *testing.T) {
 				},
 			},
 			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
+				Status: duckv1beta1.Status{
+					Conditions: duckv1beta1.Conditions{
+						{
+							Status: corev1.ConditionTrue,
+							Reason: v1beta1.TaskRunReasonSuccessful.String(),
+						},
+					},
+				},
+			},
+		},
+		{
+			ObjectMeta: metav1.ObjectMeta{
+				Name:      "tr0-7",
+				Namespace: "ns",
+				Labels:    map[string]string{"tekton.dev/clusterTask": "random"},
+			},
+			Spec: v1alpha1.TaskRunSpec{
+				TaskRef: &v1alpha1.TaskRef{
+					Name: "random",
+					Kind: v1alpha1.ClusterTaskKind,
+				},
+			},
+			Status: v1alpha1.TaskRunStatus{
+				TaskRunStatusFields: v1alpha1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						// Use real time for testing keep-since
+						Time: time.Now(),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -199,13 +262,14 @@ func TestTaskRunDelete(t *testing.T) {
 			},
 		},
 	}
+
 	type clients struct {
 		pipelineClient pipelinetest.Clients
 		dynamicClient  dynamic.Interface
 	}
 
 	seeds := make([]clients, 0)
-	for i := 0; i < 6; i++ {
+	for i := 0; i < 9; i++ {
 		cs, _ := test.SeedTestData(t, pipelinetest.Data{TaskRuns: trs, Tasks: tasks, ClusterTasks: clustertasks, Namespaces: ns})
 		cs.Pipeline.Resources = cb.APIResourceList(version, []string{"taskrun"})
 		tdc := testDynamic.Options{}
@@ -218,6 +282,7 @@ func TestTaskRunDelete(t *testing.T) {
 			cb.UnstructuredTR(trs[3], version),
 			cb.UnstructuredTR(trs[4], version),
 			cb.UnstructuredTR(trs[5], version),
+			cb.UnstructuredTR(trs[6], version),
 		)
 		if err != nil {
 			t.Errorf("unable to create dynamic client: %v", err)
@@ -241,7 +306,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[0].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
-			want:        "failed to delete TaskRun \"tr0-1\": taskruns.tekton.dev \"tr0-1\" not found",
+			want:        "taskruns.tekton.dev \"tr0-1\" not found",
 		},
 		{
 			name:        "With force delete flag (shorthand)",
@@ -286,7 +351,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[2].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
-			want:        "failed to delete TaskRun \"nonexistent\": taskruns.tekton.dev \"nonexistent\" not found",
+			want:        "taskruns.tekton.dev \"nonexistent\" not found",
 		},
 		{
 			name:        "Remove multiple non existent resources",
@@ -295,7 +360,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[2].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
-			want:        "failed to delete TaskRun \"nonexistent\": taskruns.tekton.dev \"nonexistent\" not found; failed to delete TaskRun \"nonexistent2\": taskruns.tekton.dev \"nonexistent2\" not found",
+			want:        "taskruns.tekton.dev \"nonexistent\" not found; taskruns.tekton.dev \"nonexistent2\" not found",
 		},
 		{
 			name:        "Attempt remove forgetting to include taskrun names",
@@ -313,7 +378,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[0].pipelineClient,
 			inputStream: strings.NewReader("y"),
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" (y/n): All TaskRuns associated with Task \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" (y/n): All TaskRuns(Completed) associated with Task \"random\" deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all with prompt",
@@ -322,7 +387,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[3].pipelineClient,
 			inputStream: strings.NewReader("y"),
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns in namespace \"ns\" (y/n): All TaskRuns deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns in namespace \"ns\" (y/n): All TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all with -f",
@@ -331,7 +396,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[4].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "All TaskRuns deleted in namespace \"ns\"\n",
+			want:        "All TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all keeping 2",
@@ -340,7 +405,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[4].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "All but 2 TaskRuns deleted in namespace \"ns\"\n",
+			want:        "All but 2 TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all keeping 1 with --all flag",
@@ -349,7 +414,7 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[4].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "All but 1 TaskRuns deleted in namespace \"ns\"\n",
+			want:        "All but 1 TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Keep -1 is a no go",
@@ -362,18 +427,18 @@ func TestTaskRunDelete(t *testing.T) {
 		},
 		{
 			name:        "Error from using taskrun name with --all",
-			command:     []string{"delete", "taskrun", "--all", "-n", "ns"},
-			dynamic:     seeds[4].dynamicClient,
-			input:       seeds[4].pipelineClient,
+			command:     []string{"delete", "tr0-7", "--all", "-n", "ns"},
+			dynamic:     seeds[5].dynamicClient,
+			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
 			want:        "--all flag should not have any arguments or flags specified with it",
 		},
 		{
 			name:        "Error from deleting TaskRun with non-existing Task",
-			command:     []string{"delete", "taskrun", "-t", "non-existing-task"},
-			dynamic:     seeds[4].dynamicClient,
-			input:       seeds[4].pipelineClient,
+			command:     []string{"delete", "tr0-7", "-t", "non-existing-task", "-n", "ns"},
+			dynamic:     seeds[5].dynamicClient,
+			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
 			want:        "no TaskRuns associated with Task \"non-existing-task\"",
@@ -385,11 +450,11 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" keeping 2 TaskRuns (y/n): All but 2 TaskRuns associated with Task \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" keeping 2 TaskRuns (y/n): All but 2 TaskRuns(Completed) associated with Task \"random\" deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Error from using argument with --keep",
-			command:     []string{"rm", "taskrun", "--keep", "2"},
+			command:     []string{"rm", "tr0-7", "--keep", "2", "-n", "ns"},
 			dynamic:     seeds[5].dynamicClient,
 			input:       seeds[5].pipelineClient,
 			inputStream: nil,
@@ -412,13 +477,13 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[0].pipelineClient,
 			inputStream: strings.NewReader("y"),
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" (y/n): All TaskRuns associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" (y/n): All TaskRuns(Completed) associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Error from deleting TaskRun with non-existing ClusterTask",
-			command:     []string{"delete", "taskrun", "--clustertask", "non-existing-clustertask"},
-			dynamic:     seeds[4].dynamicClient,
-			input:       seeds[4].pipelineClient,
+			command:     []string{"delete", "tr0-7", "--clustertask", "non-existing-clustertask", "-n", "ns"},
+			dynamic:     seeds[5].dynamicClient,
+			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
 			want:        "no TaskRuns associated with ClusterTask \"non-existing-clustertask\"",
@@ -430,7 +495,88 @@ func TestTaskRunDelete(t *testing.T) {
 			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" keeping 1 TaskRuns (y/n): All but 1 TaskRuns associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" keeping 1 TaskRuns (y/n): All but 1 TaskRuns(Completed) associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete all Taskruns older than 60mn",
+			command:     []string{"delete", "-f", "--all", "--keep-since", "60", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "6 expired Taskruns(Completed) has been deleted in namespace \"ns\", kept 1\n",
+		},
+		{
+			name:        "No mixing --keep-since and --keep",
+			command:     []string{"delete", "-f", "--keep-since", "60", "--keep", "5", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "cannot mix --keep and --keep-since options",
+		},
+		{
+			name:        "Delete all Taskruns older than 60mn associated with random Task",
+			command:     []string{"delete", "-f", "--task", "random", "--keep-since", "60", "-n", "ns"},
+			dynamic:     seeds[7].dynamicClient,
+			input:       seeds[7].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All but 3 expired TaskRuns associated with \"Task\" \"random\" deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Error --keep-since less than zero",
+			command:     []string{"delete", "-f", "--task", "random", "--keep-since", "-1", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "since option should not be lower than 0",
+		},
+		{
+			name:        "Error --keep-since, --all and --task cannot be used",
+			command:     []string{"delete", "-f", "--task", "random", "--keep-since", "1", "--all", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "--keep or --keep-since, --all and --task cannot be used together",
+		},
+		{
+			name:        "Delete all with default --ignore-running",
+			command:     []string{"delete", "--all", "-f", "-n", "ns", "--ignore-running"},
+			dynamic:     seeds[4].dynamicClient,
+			input:       seeds[4].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All TaskRuns(Completed) deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete all with explicit --ignore-running true",
+			command:     []string{"delete", "--all", "-f", "-n", "ns", "--ignore-running=true"},
+			dynamic:     seeds[4].dynamicClient,
+			input:       seeds[4].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All TaskRuns(Completed) deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete all with --ignore-running false",
+			command:     []string{"delete", "--all", "-f", "-n", "ns", "--ignore-running=false"},
+			dynamic:     seeds[4].dynamicClient,
+			input:       seeds[4].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All TaskRuns deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete the Task present and give error for non-existent Task",
+			command:     []string{"delete", "nonexistent", "tr0-1", "-n", "ns"},
+			dynamic:     seeds[8].dynamicClient,
+			input:       seeds[8].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "taskruns.tekton.dev \"nonexistent\" not found",
 		},
 	}
 
@@ -462,6 +608,8 @@ func TestTaskRunDelete(t *testing.T) {
 
 func TestTaskRunDelete_v1beta1(t *testing.T) {
 	version := "v1beta1"
+	clock := clockwork.NewFakeClock()
+
 	ns := []*corev1.Namespace{
 		{
 			ObjectMeta: metav1.ObjectMeta{
@@ -501,6 +649,11 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 				},
 			},
 			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -524,6 +677,11 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 				},
 			},
 			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -547,6 +705,11 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 				},
 			},
 			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -570,6 +733,11 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 				},
 			},
 			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -593,6 +761,11 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 				},
 			},
 			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -616,6 +789,40 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 				},
 			},
 			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						Time: clock.Now().Add(10 * time.Minute),
+					},
+				},
+				Status: duckv1beta1.Status{
+					Conditions: duckv1beta1.Conditions{
+						{
+							Status: corev1.ConditionTrue,
+							Reason: v1beta1.TaskRunReasonSuccessful.String(),
+						},
+					},
+				},
+			},
+		},
+		{
+			ObjectMeta: metav1.ObjectMeta{
+				Namespace: "ns",
+				Name:      "tr0-7",
+				Labels:    map[string]string{"tekton.dev/clusterTask": "random"},
+			},
+			Spec: v1beta1.TaskRunSpec{
+				TaskRef: &v1beta1.TaskRef{
+					Name: "random",
+					Kind: v1beta1.ClusterTaskKind,
+				},
+			},
+			Status: v1beta1.TaskRunStatus{
+				TaskRunStatusFields: v1beta1.TaskRunStatusFields{
+					CompletionTime: &metav1.Time{
+						// Use real time for testing keep-since
+						Time: time.Now(),
+					},
+				},
 				Status: duckv1beta1.Status{
 					Conditions: duckv1beta1.Conditions{
 						{
@@ -634,7 +841,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 	}
 
 	seeds := make([]clients, 0)
-	for i := 0; i < 6; i++ {
+	for i := 0; i < 9; i++ {
 		trs := trdata
 		cs, _ := test.SeedV1beta1TestData(t, pipelinev1beta1test.Data{TaskRuns: trs, Tasks: tasks, ClusterTasks: clustertasks, Namespaces: ns})
 		cs.Pipeline.Resources = cb.APIResourceList(version, []string{"taskrun"})
@@ -648,6 +855,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			cb.UnstructuredV1beta1TR(trdata[3], version),
 			cb.UnstructuredV1beta1TR(trdata[4], version),
 			cb.UnstructuredV1beta1TR(trdata[5], version),
+			cb.UnstructuredV1beta1TR(trdata[6], version),
 		)
 		if err != nil {
 			t.Errorf("unable to create dynamic client: %v", err)
@@ -671,7 +879,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[0].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
-			want:        "failed to delete TaskRun \"tr0-1\": taskruns.tekton.dev \"tr0-1\" not found",
+			want:        "taskruns.tekton.dev \"tr0-1\" not found",
 		},
 		{
 			name:        "With force delete flag (shorthand)",
@@ -716,7 +924,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[2].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
-			want:        "failed to delete TaskRun \"nonexistent\": taskruns.tekton.dev \"nonexistent\" not found",
+			want:        "taskruns.tekton.dev \"nonexistent\" not found",
 		},
 		{
 			name:        "Remove multiple non existent resources",
@@ -725,7 +933,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[2].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
-			want:        "failed to delete TaskRun \"nonexistent\": taskruns.tekton.dev \"nonexistent\" not found; failed to delete TaskRun \"nonexistent2\": taskruns.tekton.dev \"nonexistent2\" not found",
+			want:        "taskruns.tekton.dev \"nonexistent\" not found; taskruns.tekton.dev \"nonexistent2\" not found",
 		},
 		{
 			name:        "Attempt remove forgetting to include taskrun names",
@@ -743,7 +951,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[0].pipelineClient,
 			inputStream: strings.NewReader("y"),
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" (y/n): All TaskRuns associated with Task \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" (y/n): All TaskRuns(Completed) associated with Task \"random\" deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all with prompt",
@@ -752,7 +960,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[3].pipelineClient,
 			inputStream: strings.NewReader("y"),
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns in namespace \"ns\" (y/n): All TaskRuns deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns in namespace \"ns\" (y/n): All TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all with -f",
@@ -761,7 +969,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[4].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "All TaskRuns deleted in namespace \"ns\"\n",
+			want:        "All TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Delete all keeping 2",
@@ -770,7 +978,7 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[4].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "All but 2 TaskRuns deleted in namespace \"ns\"\n",
+			want:        "All but 2 TaskRuns(Completed) deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Keep -1 is a no go",
@@ -783,18 +991,18 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 		},
 		{
 			name:        "Error from using taskrun name with --all",
-			command:     []string{"delete", "taskrun", "--all", "-n", "ns"},
-			dynamic:     seeds[4].dynamicClient,
-			input:       seeds[4].pipelineClient,
+			command:     []string{"delete", "tr0-7", "--all", "-n", "ns"},
+			dynamic:     seeds[5].dynamicClient,
+			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
 			want:        "--all flag should not have any arguments or flags specified with it",
 		},
 		{
 			name:        "Error from deleting TaskRun with non-existing Task",
-			command:     []string{"delete", "taskrun", "-t", "non-existing-task"},
-			dynamic:     seeds[4].dynamicClient,
-			input:       seeds[4].pipelineClient,
+			command:     []string{"delete", "tr0-7", "-t", "non-existing-task", "-n", "ns"},
+			dynamic:     seeds[5].dynamicClient,
+			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
 			want:        "no TaskRuns associated with Task \"non-existing-task\"",
@@ -806,11 +1014,11 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" keeping 2 TaskRuns (y/n): All but 2 TaskRuns associated with Task \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to Task \"random\" keeping 2 TaskRuns (y/n): All but 2 TaskRuns(Completed) associated with Task \"random\" deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Error from using argument with --keep",
-			command:     []string{"rm", "taskrun", "--keep", "2"},
+			command:     []string{"rm", "tr0-7", "-n", "ns", "--keep", "2"},
 			dynamic:     seeds[5].dynamicClient,
 			input:       seeds[5].pipelineClient,
 			inputStream: nil,
@@ -824,13 +1032,13 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[0].pipelineClient,
 			inputStream: strings.NewReader("y"),
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" (y/n): All TaskRuns associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" (y/n): All TaskRuns(Completed) associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
 		},
 		{
 			name:        "Error from deleting TaskRun with non-existing ClusterTask",
-			command:     []string{"delete", "taskrun", "--clustertask", "non-existing-clustertask"},
-			dynamic:     seeds[4].dynamicClient,
-			input:       seeds[4].pipelineClient,
+			command:     []string{"delete", "tr0-7", "--clustertask", "non-existing-clustertask", "-n", "ns"},
+			dynamic:     seeds[5].dynamicClient,
+			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   true,
 			want:        "no TaskRuns associated with ClusterTask \"non-existing-clustertask\"",
@@ -842,7 +1050,88 @@ func TestTaskRunDelete_v1beta1(t *testing.T) {
 			input:       seeds[5].pipelineClient,
 			inputStream: nil,
 			wantError:   false,
-			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" keeping 2 TaskRuns (y/n): All but 2 TaskRuns associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
+			want:        "Are you sure you want to delete all TaskRuns related to ClusterTask \"random\" keeping 2 TaskRuns (y/n): All but 2 TaskRuns(Completed) associated with ClusterTask \"random\" deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete all Taskruns older than 60mn",
+			command:     []string{"delete", "-f", "--all", "--keep-since", "60", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "6 expired Taskruns(Completed) has been deleted in namespace \"ns\", kept 1\n",
+		},
+		{
+			name:        "No mixing --keep-since and --keep",
+			command:     []string{"delete", "-f", "--keep-since", "60", "--keep", "5", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "cannot mix --keep and --keep-since options",
+		},
+		{
+			name:        "Delete all Taskruns older than 60mn associated with random Task",
+			command:     []string{"delete", "-f", "--task", "random", "--keep-since", "60", "-n", "ns"},
+			dynamic:     seeds[7].dynamicClient,
+			input:       seeds[7].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All but 3 expired TaskRuns associated with \"Task\" \"random\" deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Error --keep-since less than zero",
+			command:     []string{"delete", "-f", "--task", "random", "--keep-since", "-1", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "since option should not be lower than 0",
+		},
+		{
+			name:        "Error --keep-since, --all and --task cannot be used",
+			command:     []string{"delete", "-f", "--task", "random", "--keep-since", "1", "--all", "-n", "ns"},
+			dynamic:     seeds[6].dynamicClient,
+			input:       seeds[6].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "--keep or --keep-since, --all and --task cannot be used together",
+		},
+		{
+			name:        "Delete all with default --ignore-running",
+			command:     []string{"delete", "--all", "-f", "-n", "ns"},
+			dynamic:     seeds[4].dynamicClient,
+			input:       seeds[4].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All TaskRuns(Completed) deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete all with explicit --ignore-running true",
+			command:     []string{"delete", "--all", "-f", "-n", "ns", "--ignore-running=true"},
+			dynamic:     seeds[4].dynamicClient,
+			input:       seeds[4].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All TaskRuns(Completed) deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete all with explicit --ignore-running true",
+			command:     []string{"delete", "--all", "-f", "-n", "ns", "--ignore-running=false"},
+			dynamic:     seeds[4].dynamicClient,
+			input:       seeds[4].pipelineClient,
+			inputStream: nil,
+			wantError:   false,
+			want:        "All TaskRuns deleted in namespace \"ns\"\n",
+		},
+		{
+			name:        "Delete the Task present and give error for non-existent Task",
+			command:     []string{"delete", "nonexistent", "tr0-1", "-n", "ns"},
+			dynamic:     seeds[8].dynamicClient,
+			input:       seeds[8].pipelineClient,
+			inputStream: nil,
+			wantError:   true,
+			want:        "taskruns.tekton.dev \"nonexistent\" not found",
 		},
 	}
 
